@@ -351,7 +351,8 @@ sub default_constructor {
 }
 
 {
-    package CatchEnd;
+    package # hide from CPAN
+        CatchEnd;
     use strict;
     use feature 'say';
     
@@ -376,7 +377,8 @@ sub default_constructor {
 }
 
 {
-	package ExtUtils::ParseXS;
+	package #hide from CPAN
+            ExtUtils::ParseXS;
 	my $END = "!End!\n\n";
 	my $BLOCK_regexp = '\s*(' . $ExtUtils::ParseXS::Constants::XSKeywordsAlternation . "|$END)\\s*:";
     # copy-paste from ExtUtils::ParseXS to fix Typemaps with references (&). ParseXS was simply removing it from type
